==> ejc-tax-impl-3.0.0-20210820.114525-132-sources.jar: com/ejianc/business/taxnew/controller/InvoiceOpenPoolController.java <==
package com.ejianc.business.taxnew.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.taxnew.bean.InvoiceOpenPoolEntity;
import com.ejianc.business.taxnew.service.IInvoiceOpenPoolService;
import com.ejianc.business.taxnew.vo.InvoiceOpenPoolVO;

/**
 * 销项发票池
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("invoiceOpenPool")
public class InvoiceOpenPoolController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IInvoiceOpenPoolService service; 
    
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InvoiceOpenPoolVO> saveOrUpdate(@RequestBody InvoiceOpenPoolVO saveorUpdateVO) {
    	InvoiceOpenPoolEntity entity = BeanMapper.map(saveorUpdateVO, InvoiceOpenPoolEntity.class);
    	service.saveOrUpdate(entity, false);
    	InvoiceOpenPoolVO vo = BeanMapper.map(entity, InvoiceOpenPoolVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceOpenPoolVO> queryDetail(Long id) {
    	InvoiceOpenPoolEntity entity = service.selectById(id);
    	InvoiceOpenPoolVO vo = BeanMapper.map(entity, InvoiceOpenPoolVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InvoiceOpenPoolVO> vos) {
        service.removeByIds(vos.stream().map(InvoiceOpenPoolVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InvoiceOpenPoolVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        
        IPage<InvoiceOpenPoolEntity> page = service.queryPage(param,false);
        IPage<InvoiceOpenPoolVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceOpenPoolVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 根据登记id查询数据
     * @param registId
     * @return
     */
    @RequestMapping(value = "/queryListByRegistId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JSONObject> queryListByRegistId(Long registId){
        JSONObject data = new JSONObject();
        List<InvoiceOpenPoolVO> list = new ArrayList<>();
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("regist_id" ,registId);
        List<InvoiceOpenPoolEntity> invoiceOpenPoolEntityList =service.list(queryWrapper);
        if(CollectionUtils.isNotEmpty(invoiceOpenPoolEntityList)) {
            list = BeanMapper.mapList(invoiceOpenPoolEntityList, InvoiceOpenPoolVO.class);
        }
        data.put("contractItemList",list);
        return CommonResponse.success("查询已登记发票成功！", data);
    }
}

==> ejc-tax-impl-3.0.0-20210825.073925-141-sources.jar: com/ejianc/business/taxnew/controller/InvoiceOpenPoolController.java <==
package com.ejianc.business.taxnew.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.taxnew.bean.InvoiceOpenRegistEntity;
import com.ejianc.business.taxnew.vo.InvoiceOpenRegistVO;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.taxnew.bean.InvoiceOpenPoolEntity;
import com.ejianc.business.taxnew.service.IInvoiceOpenPoolService;
import com.ejianc.business.taxnew.vo.InvoiceOpenPoolVO;

import javax.servlet.http.HttpServletResponse;

/**
 * 销项发票池
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("invoiceOpenPool")
public class InvoiceOpenPoolController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IInvoiceOpenPoolService service; 
    
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InvoiceOpenPoolVO> saveOrUpdate(@RequestBody InvoiceOpenPoolVO saveorUpdateVO) {
    	InvoiceOpenPoolEntity entity = BeanMapper.map(saveorUpdateVO, InvoiceOpenPoolEntity.class);
    	service.saveOrUpdate(entity, false);
    	InvoiceOpenPoolVO vo = BeanMapper.map(entity, InvoiceOpenPoolVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceOpenPoolVO> queryDetail(Long id) {
    	InvoiceOpenPoolEntity entity = service.selectById(id);
    	InvoiceOpenPoolVO vo = BeanMapper.map(entity, InvoiceOpenPoolVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InvoiceOpenPoolVO> vos) {
        service.removeByIds(vos.stream().map(InvoiceOpenPoolVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InvoiceOpenPoolVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        
        IPage<InvoiceOpenPoolEntity> page = service.queryPage(param,false);
        IPage<InvoiceOpenPoolVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceOpenPoolVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 根据登记id查询数据
     * @param registId
     * @return
     */
    @RequestMapping(value = "/queryListByRegistId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JSONObject> queryListByRegistId(Long registId){
        JSONObject data = new JSONObject();
        List<InvoiceOpenPoolVO> list = new ArrayList<>();
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("regist_id" ,registId);
        List<InvoiceOpenPoolEntity> invoiceOpenPoolEntityList =service.list(queryWrapper);
        if(CollectionUtils.isNotEmpty(invoiceOpenPoolEntityList)) {
            list = BeanMapper.mapList(invoiceOpenPoolEntityList, InvoiceOpenPoolVO.class);
        }
        data.put("contractItemList",list);
        return CommonResponse.success("查询已登记发票成功！", data);
    }
    /**
     * 导出(待登记)
     * @param queryParam
     * @param response
     */
    @PostMapping(value = "excelExport")
    public void excelExport(@RequestBody QueryParam queryParam, HttpServletResponse response) {

        queryParam.setPageIndex(1);
        queryParam.setPageSize(10000);
        IPage<InvoiceOpenPoolEntity> pageData = service.queryPage(queryParam, false);
        List<InvoiceOpenPoolVO> voList = new ArrayList<InvoiceOpenPoolVO>();
        if(CollectionUtils.isNotEmpty(pageData.getRecords())) {
            pageData.getRecords().forEach(invoiceOpenPoolEntity -> {
                InvoiceOpenPoolVO r = BeanMapper.map(invoiceOpenPoolEntity, InvoiceOpenPoolVO.class);

                if(r.getInvoiceType() == 1){
                    r.setInvoiceTypeName("增值税专用发票");
                }else if(r.getInvoiceType() ==2){
                    r.setInvoiceTypeName("增值税普通发票");
                }else{
                    r.setInvoiceTypeName("其它");
                }


                voList.add(r);
            });
        }
        Map<String, Object> beans = new HashMap<String, Object>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("invoiceOpenRegistPool-export.xlsx", beans, response);
    }
}
